@@ -105,6 +105,10 @@ def get_ipmi_address(node):
         if '//' in value:
             url = urllib.parse.urlparse(value)
             value = url.hostname
+
+        # Strip brackets in case used on IPv6 address.
+        value = value.strip('[').strip(']')
+
         try:
             addrinfo = socket.getaddrinfo(value, None, 0, 0, socket.SOL_TCP)
             for family, socket_type, proto, canon_name, sockaddr in addrinfo:
@@ -120,7 +124,7 @@ def get_ipmi_address(node):
             msg = _('Failed to resolve the hostname (%(value)s)'
                     ' for node %(uuid)s')
             raise utils.Error(msg % {'value': value,
-                                     'uuid': node.uuid},
+                                     'uuid': node.id},
                               node_info=node)
 
         return (value, ipv4, ipv6) if ipv4 or ipv6 else none_address
@@ -178,7 +182,6 @@ def get_node(node_id, ironic=None, **kwargs):
 
     try:
         node = ironic.get_node(node_id, **kwargs)
-        node.uuid = node.id
     except os_exc.ResourceNotFound:
         raise NotFound(node_id)
     except os_exc.BadRequestException as exc:
@@ -244,7 +247,7 @@ def lookup_node_by_bmc_addresses(addresses, introspection_data=None,
     #                 inspected, i.e. inspect wait, and then fallback
     #                 to the rest of the physical nodes so we limit
     #                 overall-impact of the operation.
-    nodes = ironic.nodes(fields=('id', 'driver_info'), limit=None)
+    nodes = ironic.nodes(fields=('uuid', 'driver_info'), limit=None)
     found = set()
     for node in nodes:
         bmc_address, bmc_ipv4, bmc_ipv6 = get_ipmi_address(node)
