@@ -39,6 +39,7 @@ CONF = ironic_inspector.conf.CONF
 
 
 _app = flask.Flask(__name__)
+_app.url_map.strict_slashes = False
 _wsgi_app = _app.wsgi_app
 
 LOG = utils.getProcessingLogger(__name__)
@@ -77,8 +78,10 @@ def _init_middleware():
 
 def get_app():
     """Get the flask instance."""
-    _init_middleware()
-    return _app
+    with _app.app_context():
+        _init_middleware()
+        start_coordinator()
+        return _app
 
 
 # TODO(kaifeng) Extract rpc related code into a rpcapi module
@@ -195,7 +198,6 @@ def convert_exceptions(func):
     return wrapper
 
 
-@_app.before_first_request
 def start_coordinator():
     """Create a coordinator instance for non-standalone case."""
     if not CONF.standalone:
@@ -279,17 +281,12 @@ def api(path, is_public_api=False, rule=None, verb_to_rule_map=None,
                           as public, with minimal access enforcement
     :param rule: API access policy rule to enforce.
                  If rule is None, the 'default' policy rule will be enforced,
-                 which is "deny all" if not overridden in policy confif file.
+                 which is "deny all" if not overridden in policy config file.
     :param verb_to_rule_map: if both rule and this are given,
                              defines mapping between http verbs (uppercase)
                              and strings to format the 'rule' string with
     :param kwargs: all the rest kwargs are passed to flask app.route
     """
-    # Force uniform behavior with regards to trailing slashes
-    if not path.endswith('/'):
-        path = path + '/'
-    flask_kwargs['strict_slashes'] = False
-
     def outer(func):
         @_app.route(path, **flask_kwargs)
         @convert_exceptions
@@ -329,7 +326,6 @@ def api_root():
      methods=['GET'])
 def version_root(version):
     pat = re.compile(r'^\/%s\/[^\/]*?/?$' % version)
-
     resources = []
     for url in _app.url_map.iter_rules():
         if pat.match(str(url)):
