@@ -13,10 +13,11 @@
 # under the License.
 
 """Tests for introspection rules."""
-import mock
+from unittest import mock
+
 from oslo_utils import uuidutils
 
-from ironic_inspector import db
+from ironic_inspector.db import api as db
 from ironic_inspector.plugins import base as plugins_base
 from ironic_inspector import rules
 from ironic_inspector.test import base as test_base
@@ -40,6 +41,8 @@ class BaseTest(test_base.NodeTest):
             'local_gb': 42,
         }
 
+        self.scope = "inner circle"
+
     @staticmethod
     def condition_defaults(condition):
         condition = condition.copy()
@@ -56,7 +59,21 @@ class TestCreateRule(BaseTest):
         self.assertTrue(rule_json.pop('uuid'))
         self.assertEqual({'description': None,
                           'conditions': [],
-                          'actions': self.actions_json},
+                          'actions': self.actions_json,
+                          'scope': None},
+                         rule_json)
+
+    def test_create_action_none_value(self):
+        self.actions_json = [{'action': 'set-attribute',
+                              'path': '/properties/cpus', 'value': None}]
+        rule = rules.create([], self.actions_json)
+        rule_json = rule.as_dict()
+
+        self.assertTrue(rule_json.pop('uuid'))
+        self.assertEqual({'description': None,
+                          'conditions': [],
+                          'actions': self.actions_json,
+                          'scope': None},
                          rule_json)
 
     def test_duplicate_uuid(self):
@@ -82,7 +99,8 @@ class TestCreateRule(BaseTest):
         self.assertEqual({'description': None,
                           'conditions': [BaseTest.condition_defaults(cond)
                                          for cond in self.conditions_json],
-                          'actions': self.actions_json},
+                          'actions': self.actions_json,
+                          'scope': None},
                          rule_json)
 
     def test_invalid_condition(self):
@@ -145,6 +163,17 @@ class TestCreateRule(BaseTest):
                                rules.create,
                                self.conditions_json, self.actions_json)
 
+    def test_scope(self):
+        rule = rules.create([], self.actions_json, scope=self.scope)
+        rule_json = rule.as_dict()
+
+        self.assertTrue(rule_json.pop('uuid'))
+        self.assertEqual({'description': None,
+                          'conditions': [],
+                          'actions': self.actions_json,
+                          'scope': self.scope},
+                         rule_json)
+
 
 class TestGetRule(BaseTest):
     def setUp(self):
@@ -158,7 +187,8 @@ class TestGetRule(BaseTest):
         self.assertEqual({'description': None,
                           'conditions': [BaseTest.condition_defaults(cond)
                                          for cond in self.conditions_json],
-                          'actions': self.actions_json},
+                          'actions': self.actions_json,
+                          'scope': None},
                          rule_json)
 
     def test_not_found(self):
@@ -181,11 +211,9 @@ class TestDeleteRule(BaseTest):
     def test_delete(self):
         rules.delete(self.uuid)
 
-        self.assertEqual([(self.uuid2,)], db.model_query(db.Rule.uuid).all())
-        self.assertFalse(db.model_query(db.RuleCondition)
-                         .filter_by(rule=self.uuid).all())
-        self.assertFalse(db.model_query(db.RuleAction)
-                         .filter_by(rule=self.uuid).all())
+        self.assertEqual([self.uuid2], [r.uuid for r in db.get_rules()])
+        self.assertFalse(db.get_rules_conditions(rule=self.uuid))
+        self.assertFalse(db.get_rules_actions(rule=self.uuid))
 
     def test_delete_non_existing(self):
         self.assertRaises(utils.Error, rules.delete, 'foo')
@@ -193,9 +221,9 @@ class TestDeleteRule(BaseTest):
     def test_delete_all(self):
         rules.delete_all()
 
-        self.assertFalse(db.model_query(db.Rule).all())
-        self.assertFalse(db.model_query(db.RuleCondition).all())
-        self.assertFalse(db.model_query(db.RuleAction).all())
+        self.assertFalse(db.get_rules())
+        self.assertFalse(db.get_rules_conditions())
+        self.assertFalse(db.get_rules_actions())
 
 
 @mock.patch.object(plugins_base, 'rule_conditions_manager', autospec=True)
@@ -546,3 +574,61 @@ class TestApply(BaseTest):
                     self.node_info, data=self.data)
             else:
                 self.assertFalse(rule.apply_actions.called)
+
+
+@mock.patch.object(rules, 'get_all', autospec=True)
+class TestRuleScope(BaseTest):
+    """Test that rules are only applied on the nodes that fall in their scope.
+
+    Check that:
+    - global rule is applied to all nodes
+    - different rules with scopes are applied to different nodes
+    - rule without matching scope is not applied
+    """
+
+    def setUp(self):
+        super(TestRuleScope, self).setUp()
+
+        """
+        rule_global
+        rule_scope_1
+        rule_scope_2
+        rule_out_scope
+        """
+
+        self.rules = [rules.IntrospectionRule("", "", "", "", None),
+                      rules.IntrospectionRule("", "", "", "", "scope_1"),
+                      rules.IntrospectionRule("", "", "", "", "scope_2"),
+                      rules.IntrospectionRule("", "", "", "", "scope_3")]
+        for r in self.rules:
+            r.check_conditions = mock.Mock()
+            r.check_conditions.return_value = True
+            r.apply_actions = mock.Mock()
+            r.apply_actions.return_value = True
+
+    def test_node_no_scope(self, mock_get_all):
+        mock_get_all.return_value = self.rules
+        self.node_info.node().properties['inspection_scope'] = None
+        rules.apply(self.node_info, self.data)
+        self.rules[0].apply_actions.assert_called_once()  # global
+        self.rules[1].apply_actions.assert_not_called()   # scope_1
+        self.rules[2].apply_actions.assert_not_called()   # scope_2
+        self.rules[3].apply_actions.assert_not_called()   # scope_3
+
+    def test_node_scope_1(self, mock_get_all):
+        mock_get_all.return_value = self.rules
+        self.node_info.node().properties['inspection_scope'] = "scope_1"
+        rules.apply(self.node_info, self.data)
+        self.rules[0].apply_actions.assert_called_once()  # global
+        self.rules[1].apply_actions.assert_called_once()   # scope_1
+        self.rules[2].apply_actions.assert_not_called()   # scope_2
+        self.rules[3].apply_actions.assert_not_called()   # scope_3
+
+    def test_node_scope_2(self, mock_get_all):
+        mock_get_all.return_value = self.rules
+        self.node_info.node().properties['inspection_scope'] = "scope_2"
+        rules.apply(self.node_info, self.data)
+        self.rules[0].apply_actions.assert_called_once()  # global
+        self.rules[1].apply_actions.assert_not_called()   # scope_1
+        self.rules[2].apply_actions.assert_called_once()   # scope_2
+        self.rules[3].apply_actions.assert_not_called()   # scope_3
